/// <reference types="node" />
/// <reference types="node" />
export interface CompileFileArguments {
    filename: string;
    output?: string;
    compileAsModule?: boolean;
    getPreservedRanges?: (source: string) => [number, number][];
    compress?: boolean;
}
export interface CompileCodeOptions {
    filename?: string;
    replacementSource?: Buffer;
    compress?: boolean;
}
export interface SystemInfo {
    nodeVersion: string;
    arch: string;
}
export interface Content {
    systemInfo: Uint8Array;
    dummyCode: Uint8Array;
    bytecodeBuffer: Uint8Array;
}
/**
 * install source-map-support with value for retrieveSourceMap function that will be used to retrieve the source map file content
 * @param options
 */
export declare function sourceMapSetup(options?: any): void;
export declare function getSystemInfo(): SystemInfo;
/**
 * Generates v8 bytecode buffer.
 * @param   {string} javascriptCode JavaScript source that will be compiled to bytecode.
 * @returns {Buffer} The generated bytecode.
 */
export declare function compileCode(javascriptCode: string, options?: CompileCodeOptions): Buffer;
/**
 * Compiles JavaScript file to .jsb/.jsbz file.
 * @param   {object|string} args
 * @param   {string}          args.filename The JavaScript source file that will be compiled
 * @param   {boolean}         [args.compileAsModule=true] If true, the output will be a commonjs module
 * @param   {string}          [args.output=filename.jsb] The output filename. Defaults to the same path and name of the original file, but with `.jsb/.jsbz` extension.
 * @returns {string}        The compiled filename
 */
export declare function compileFile(args: CompileFileArguments | string): string;
/**
 * Runs v8 bytecode buffer and returns the result.
 * @param   {Buffer} bytecodeBuffer The buffer object that was created using compileCode function.
 * @returns {any}    The result of the very last statement executed in the script.
 */
export declare function runBytecode(bytecodeBuffer: Buffer, filename: string): any;
/**
 * Runs .jsb/.jsbz file and returns the result.
 * @param   {string} filename
 * @returns {any}    The result of the very last statement executed in the script.
 */
export declare function runBytecodeFile(filename: string): any;
//# sourceMappingURL=bytenode.d.ts.map